==> haskell-pager-0.1.1.0-163-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pager.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pager
version:              0.1.1.0
visibility:           public
id:                   pager-0.1.1.0-GkqQXA4b7gq8N1dZ22rnK9
key:                  pager-0.1.1.0-GkqQXA4b7gq8N1dZ22rnK9
license:              BSD-2-Clause
copyright:            Copyright (c) 2015, Peter Harpending.
maintainer:           peter@harpending.org
author:               Peter Harpending
homepage:             https://github.com/pharpend/pager
synopsis:             Open up a pager, like '\''less'\'' or '\''more'\''
description:
    This opens up the user'\''s $PAGER. On Linux, this is usually called @less@. On
    the various BSDs, this is usually @more@.

    CHANGES

    [0.1.1.0] Add @printOrPage@ function and @sendToPagerStrict@ function.

category:             Data, System, Text
abi:                  82a7bb950dbd78d3bc3b685525a5017e
exposed:              True
exposed-modules:      System.Pager
import-dirs:          /usr/lib/ghc-9.4.8/site-local/pager-0.1.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pager-0.1.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pager-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pager
hs-libraries:         HSpager-0.1.1.0-GkqQXA4b7gq8N1dZ22rnK9
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-He7eBVLUt4xGGZqD48fwnz
    conduit-extra-1.3.8-FPYZ2SHai5SFHdZmLa2NAW directory-1.3.7.1
    process-1.6.18.0 resourcet-1.2.6-L35jMXzxMSIDSY1RilUGui
    safe-0.3.21-EJlQ7Hm9gwUGpRoyGimKjN terminfo-0.4.1.5 text-2.0.2
    transformers-0.5.6.2 unix-2.7.3

haddock-interfaces:   /usr/share/doc/haskell-pager/html/pager.haddock
haddock-html:         /usr/share/doc/haskell-pager/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pager-0.1.1.0-164-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pager.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pager
version:              0.1.1.0
visibility:           public
id:                   pager-0.1.1.0-KlcRnyozTOKEHokiJjJIIO
key:                  pager-0.1.1.0-KlcRnyozTOKEHokiJjJIIO
license:              BSD-2-Clause
copyright:            Copyright (c) 2015, Peter Harpending.
maintainer:           peter@harpending.org
author:               Peter Harpending
homepage:             https://github.com/pharpend/pager
synopsis:             Open up a pager, like '\''less'\'' or '\''more'\''
description:
    This opens up the user'\''s $PAGER. On Linux, this is usually called @less@. On
    the various BSDs, this is usually @more@.

    CHANGES

    [0.1.1.0] Add @printOrPage@ function and @sendToPagerStrict@ function.

category:             Data, System, Text
abi:                  5b9878b8365465de73a190ad55af9636
exposed:              True
exposed-modules:      System.Pager
import-dirs:          /usr/lib/ghc-9.4.8/site-local/pager-0.1.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pager-0.1.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pager-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pager
hs-libraries:         HSpager-0.1.1.0-KlcRnyozTOKEHokiJjJIIO
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-KIgc8u8jbkN2A9El9r6mby
    conduit-extra-1.3.8-7AsukhXAhG9EP9Xj5iNAEL directory-1.3.7.1
    process-1.6.18.0 resourcet-1.2.6-I2UUpqDV6YBEHmvIRfrjlc
    safe-0.3.21-KJlW7jRgZb73RD220AjTnZ terminfo-0.4.1.5 text-2.0.2
    transformers-0.5.6.2 unix-2.7.3

haddock-interfaces:   /usr/share/doc/haskell-pager/html/pager.haddock
haddock-html:         /usr/share/doc/haskell-pager/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
